summaryrefslogtreecommitdiffstats
path: root/tests/mir-opt/const_prop/boxes.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/mir-opt/const_prop/boxes.rs')
-rw-r--r--tests/mir-opt/const_prop/boxes.rs8
1 files changed, 5 insertions, 3 deletions
diff --git a/tests/mir-opt/const_prop/boxes.rs b/tests/mir-opt/const_prop/boxes.rs
index d287830db..66e8c24d4 100644
--- a/tests/mir-opt/const_prop/boxes.rs
+++ b/tests/mir-opt/const_prop/boxes.rs
@@ -4,11 +4,13 @@
// ignore-wasm32
// ignore-wasm64
#![feature(box_syntax)]
// Note: this test verifies that we, in fact, do not const prop `box`
// EMIT_MIR boxes.main.ConstProp.diff
fn main() {
- let x = *(box 42) + 0;
+ let x = *(#[rustc_box]
+ Box::new(42))
+ + 0;
}
@@ -4,11 +4,13 @@
// ignore-wasm32
// ignore-wasm64
-#![feature(box_syntax)]
+#![feature(rustc_attrs, stmt_expr_attributes)]
-// Note: this test verifies that we, in fact, do not const prop `box`
+// Note: this test verifies that we, in fact, do not const prop `#[rustc_box]`
// EMIT_MIR boxes.main.ConstProp.diff
fn main() {